==> jc-1.4.0.tar.gz: java/security/AccessControlException.h <==
// public class java.security.AccessControlException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 767fc1626c63609e java_lang_SecurityException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 257de8881330511f java_security_AccessControlException

// header file dependencies
// @dep_header java_lang_SecurityException

#include "java/lang/SecurityException.h"

#ifndef _JC_java_security_AccessControlException_H_
#define _JC_java_security_AccessControlException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Permission$object;

// Typedefs
typedef struct _jc_java_security_AccessControlException$sub_refs	_jc_java_security_AccessControlException$sub_refs;
typedef struct _jc_java_security_AccessControlException$sub_nonrefs	_jc_java_security_AccessControlException$sub_nonrefs;
typedef struct _jc_java_security_AccessControlException$refs	_jc_java_security_AccessControlException$refs;
typedef struct _jc_java_security_AccessControlException$nonrefs	_jc_java_security_AccessControlException$nonrefs;
typedef struct _jc_java_security_AccessControlException$object	_jc_java_security_AccessControlException$object;

typedef struct _jc_java_security_AccessControlException$fields_struct	_jc_java_security_AccessControlException$fields_struct;
typedef const struct _jc_java_security_AccessControlException$vmethods	_jc_java_security_AccessControlException$vmethods;
typedef const struct _jc_java_security_AccessControlException$vtable	_jc_java_security_AccessControlException$vtable;
typedef const struct _jc_java_security_AccessControlException$vtype	_jc_java_security_AccessControlException$vtype;

// Class fields structure
struct _jc_java_security_AccessControlException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_AccessControlException$fields_struct _jc_java_security_AccessControlException$class_fields;

// Constructors
extern void _jc_java_security_AccessControlException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_security_AccessControlException$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_security_AccessControlException$method$_init$d6c4715d896562d7(_jc_env *, struct _jc_java_security_AccessControlException$object *, struct _jc_java_lang_String$object *, struct _jc_java_security_Permission$object *);

// Virtual methods
extern struct _jc_java_security_Permission$object *_jc_java_security_AccessControlException$method$getPermission$5ed14cf5cad2ace7(_jc_env *, struct _jc_java_security_AccessControlException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_AccessControlException$method_info$getPermission$5ed14cf5cad2ace7;

// Virtual methods structure
struct _jc_java_security_AccessControlException$vmethods {
	struct _jc_java_security_Permission$object	*(*getPermission$5ed14cf5cad2ace7)(_jc_env *, struct _jc_java_security_AccessControlException$object *);
};

// Vtable
struct _jc_java_security_AccessControlException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_SecurityException$vmethods	java_lang_SecurityException;
	_jc_java_security_AccessControlException$vmethods	java_security_AccessControlException;
};

// Vtype
struct _jc_java_security_AccessControlException$vtype {
	_jc_type			type;
	_jc_java_security_AccessControlException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_AccessControlException$sub_refs {
	struct _jc_java_security_Permission$object	*perm;
};

// Reference instance fields (object)
struct _jc_java_security_AccessControlException$refs {
    _jc_java_security_AccessControlException$sub_refs	java_security_AccessControlException;
    _jc_java_lang_SecurityException$sub_refs	java_lang_SecurityException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_AccessControlException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_AccessControlException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_SecurityException$sub_nonrefs	java_lang_SecurityException;
    _jc_java_security_AccessControlException$sub_nonrefs	java_security_AccessControlException;
};

// Object instance structure
struct _jc_java_security_AccessControlException$object {
	_jc_java_security_AccessControlException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_AccessControlException$vtype	*vtype;
	_jc_java_security_AccessControlException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_AccessControlException$vtype _jc_java_security_AccessControlException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_AccessControlException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_AccessControlException$class_object;

#endif	/* _JC_java_security_AccessControlException_H_ */

==> jc-1.4.6.tar.gz: java/security/AccessControlException.h <==
// public class java.security.AccessControlException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 767fc1626c63609e java_lang_SecurityException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 257de8881330511f java_security_AccessControlException

// header file dependencies
// @dep_header java_lang_SecurityException

#include "java/lang/SecurityException.h"

#ifndef _JC_java_security_AccessControlException_H_
#define _JC_java_security_AccessControlException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Permission$object;

// Typedefs
typedef struct _jc_java_security_AccessControlException$sub_refs	_jc_java_security_AccessControlException$sub_refs;
typedef struct _jc_java_security_AccessControlException$sub_nonrefs	_jc_java_security_AccessControlException$sub_nonrefs;
typedef struct _jc_java_security_AccessControlException$refs	_jc_java_security_AccessControlException$refs;
typedef struct _jc_java_security_AccessControlException$nonrefs	_jc_java_security_AccessControlException$nonrefs;
typedef struct _jc_java_security_AccessControlException$object	_jc_java_security_AccessControlException$object;

typedef struct _jc_java_security_AccessControlException$fields_struct	_jc_java_security_AccessControlException$fields_struct;
typedef const struct _jc_java_security_AccessControlException$vmethods	_jc_java_security_AccessControlException$vmethods;
typedef const struct _jc_java_security_AccessControlException$vtable	_jc_java_security_AccessControlException$vtable;
typedef const struct _jc_java_security_AccessControlException$vtype	_jc_java_security_AccessControlException$vtype;

// Class fields structure
struct _jc_java_security_AccessControlException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_AccessControlException$fields_struct _jc_java_security_AccessControlException$class_fields;

// Constructors
extern void _jc_java_security_AccessControlException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_security_AccessControlException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_AccessControlException$method$_init$d6c4715d896562d7(_jc_env *, struct _jc_java_security_AccessControlException$object *, struct _jc_java_lang_String$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_security_Permission$object *_jc_java_security_AccessControlException$method$getPermission$5ed14cf5cad2ace7(_jc_env *, struct _jc_java_security_AccessControlException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_AccessControlException$method_info$getPermission$5ed14cf5cad2ace7;

// Virtual methods structure
struct _jc_java_security_AccessControlException$vmethods {
	struct _jc_java_security_Permission$object	*(*getPermission$5ed14cf5cad2ace7)(_jc_env *, struct _jc_java_security_AccessControlException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_AccessControlException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_SecurityException$vmethods	java_lang_SecurityException;
	_jc_java_security_AccessControlException$vmethods	java_security_AccessControlException;
};

// Vtype
struct _jc_java_security_AccessControlException$vtype {
	_jc_type			type;
	_jc_java_security_AccessControlException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_AccessControlException$sub_refs {
	struct _jc_java_security_Permission$object	*perm;
};

// Reference instance fields (object)
struct _jc_java_security_AccessControlException$refs {
    _jc_java_security_AccessControlException$sub_refs	java_security_AccessControlException;
    _jc_java_lang_SecurityException$sub_refs	java_lang_SecurityException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_AccessControlException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_AccessControlException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_SecurityException$sub_nonrefs	java_lang_SecurityException;
    _jc_java_security_AccessControlException$sub_nonrefs	java_security_AccessControlException;
};

// Object instance structure
struct _jc_java_security_AccessControlException$object {
	_jc_java_security_AccessControlException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_AccessControlException$vtype	*vtype;
	_jc_java_security_AccessControlException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_AccessControlException$vtype _jc_java_security_AccessControlException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_AccessControlException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_AccessControlException$class_object;

#endif	/* _JC_java_security_AccessControlException_H_ */
